@@ -44,5 +44,6 @@ class ExtractorTest(unittest.TestCase):
     def test_mime(self):
         mimetext = ''.join(open(unforward.get_data("examples/gmail_forward_2.mime")))
         result = self.extractor.extract(mimetext)
-        print result
+        expected = {'body': '<div><div><div>Comodo,<br/>\n<br/></div>I have to say that I am impressed by your thoroughness on our company background check. 5 stars for actually doing a background check.<br/><br/></div>Our accountant Tara is registered under the Chartered Professional Accountants of Ontario.<br/>\n<br/></div>Brad<br/>', 'sender': u'brad@getsensibill.com'}
+        self.assertEqual(result, expected)
         
